Installation
============

Install ModernGL with :command:`pip`:

.. code-block:: sh

    $ pip install ModernGL

Version check:

.. code-block:: sh

    $ python -m moderngl --version  # 5.0.0 and above
    $ python -m ModernGL --version  # before 5.0.0

.. note::

    - The package name is "ModernGL" for `ModernGL<5.0.0`
    - The package name is "moderngl" for `ModernGL>=5.0.0`

.. toctree::
    :maxdepth: 2
